@@ -190,9 +190,7 @@ class TestV3Public:
             ("k3.xxx.pie.AAAAAAAAAAAAAAAA", "Invalid PASERK type: xxx."),
         ],
     )
-    def test_v3_public_from_paserk_with_wrapping_key_and_invalid_args(
-        self, paserk, msg
-    ):
+    def test_v3_public_from_paserk_with_wrapping_key_and_invalid_args(self, paserk, msg):
 
         with pytest.raises(ValueError) as err:
             V3Public.from_paserk(paserk, wrapping_key=token_bytes(32))
